# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxo/block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'utxo/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18utxo/block_message.proto\x12\rutxo_messages\"l\n\x0c\x42lockMessage\x12*\n\x06Header\x18\x01 \x01(\x0b\x32\x1a.utxo_messages.BlockHeader\x12\x30\n\x0cTransactions\x18\x02 \x03(\x0b\x32\x1a.utxo_messages.Transaction\"\xca\x02\n\x0b\x42lockHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x15\n\rConfirmations\x18\x02 \x01(\x03\x12\x0c\n\x04Size\x18\x03 \x01(\x05\x12\x14\n\x0cStrippedSize\x18\x04 \x01(\x05\x12\x0e\n\x06Weight\x18\x05 \x01(\x05\x12\x0e\n\x06Height\x18\x06 \x01(\x03\x12\x0f\n\x07Version\x18\x07 \x01(\x05\x12\x12\n\nVersionHex\x18\x08 \x01(\x0c\x12\x12\n\nMerkleRoot\x18\t \x01(\x0c\x12\x0c\n\x04Time\x18\n \x01(\x03\x12\x12\n\nMedianTime\x18\x0b \x01(\x03\x12\r\n\x05Nonce\x18\x0c \x01(\r\x12\x0c\n\x04\x42its\x18\r \x01(\x0c\x12\x12\n\nDifficulty\x18\x0e \x01(\x01\x12\x11\n\tChainwork\x18\x0f \x01(\x0c\x12\x0b\n\x03NTx\x18\x10 \x01(\r\x12\x14\n\x0cPreviousHash\x18\x11 \x01(\x0c\x12\x10\n\x08NextHash\x18\x12 \x01(\x0c\"\xa3\x01\n\x0bTransaction\x12\x30\n\x06Header\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionHeader\x12/\n\x06Inputs\x18\x02 \x03(\x0b\x32\x1f.utxo_messages.TransactionInput\x12\x31\n\x07Outputs\x18\x03 \x03(\x0b\x32 .utxo_messages.TransactionOutput\"\x8a\x01\n\x11TransactionHeader\x12\x0b\n\x03Hex\x18\x01 \x01(\x0c\x12\n\n\x02Id\x18\x02 \x01(\x0c\x12\x0c\n\x04Hash\x18\x03 \x01(\x0c\x12\x0c\n\x04Size\x18\x04 \x01(\x05\x12\r\n\x05VSize\x18\x05 \x01(\x05\x12\x0e\n\x06Weight\x18\x06 \x01(\x05\x12\x0f\n\x07Version\x18\x07 \x01(\r\x12\x10\n\x08LockTime\x18\x08 \x01(\r\"\x90\x01\n\x10TransactionInput\x12\x10\n\x08\x43oinbase\x18\x01 \x01(\x0c\x12\x0c\n\x04TxId\x18\x02 \x01(\x0c\x12\x0c\n\x04VOut\x18\x03 \x01(\r\x12+\n\tScriptSig\x18\x04 \x01(\x0b\x32\x18.utxo_messages.ScriptSig\x12\x10\n\x08Sequence\x18\x05 \x01(\r\x12\x0f\n\x07Witness\x18\x06 \x03(\t\"%\n\tScriptSig\x12\x0b\n\x03\x41sm\x18\x01 \x01(\t\x12\x0b\n\x03Hex\x18\x02 \x01(\x0c\"`\n\x11TransactionOutput\x12\r\n\x05Value\x18\x01 \x01(\x01\x12\t\n\x01N\x18\x02 \x01(\r\x12\x31\n\x0cScriptPubKey\x18\x03 \x01(\x0b\x32\x1b.utxo_messages.ScriptPubKey\"U\n\x0cScriptPubKey\x12\x0b\n\x03\x41sm\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03Hex\x18\x03 \x01(\x0c\x12\x0c\n\x04Type\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\"e\n\x1eTransactionOutputWithBlockHash\x12\x30\n\x06Output\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionOutput\x12\x11\n\tBlockHash\x18\x02 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxo.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BLOCKMESSAGE']._serialized_start=43
  _globals['_BLOCKMESSAGE']._serialized_end=151
  _globals['_BLOCKHEADER']._serialized_start=154
  _globals['_BLOCKHEADER']._serialized_end=484
  _globals['_TRANSACTION']._serialized_start=487
  _globals['_TRANSACTION']._serialized_end=650
  _globals['_TRANSACTIONHEADER']._serialized_start=653
  _globals['_TRANSACTIONHEADER']._serialized_end=791
  _globals['_TRANSACTIONINPUT']._serialized_start=794
  _globals['_TRANSACTIONINPUT']._serialized_end=938
  _globals['_SCRIPTSIG']._serialized_start=940
  _globals['_SCRIPTSIG']._serialized_end=977
  _globals['_TRANSACTIONOUTPUT']._serialized_start=979
  _globals['_TRANSACTIONOUTPUT']._serialized_end=1075
  _globals['_SCRIPTPUBKEY']._serialized_start=1077
  _globals['_SCRIPTPUBKEY']._serialized_end=1162
  _globals['_TRANSACTIONOUTPUTWITHBLOCKHASH']._serialized_start=1164
  _globals['_TRANSACTIONOUTPUTWITHBLOCKHASH']._serialized_end=1265
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/parsed_abi_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'evm/parsed_abi_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"evm/parsed_abi_block_message.proto\x12\x0c\x65vm_messages\x1a\x17\x65vm/block_message.proto\"\xe6\x01\n\rArgumentValue\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x10\n\x08IsHashed\x18\x02 \x01(\x08\x12\x10\n\x06String\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x42ytes\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x04UInt\x18\x05 \x01(\x04H\x00\x12\r\n\x03Int\x18\x06 \x01(\x03H\x00\x12\x0e\n\x04\x42ool\x18\x07 \x01(\x08H\x00\x12,\n\x05\x41rray\x18\n \x01(\x0b\x32\x1b.evm_messages.ArgumentArrayH\x00\x12,\n\x05Tuple\x18\x0b \x01(\x0b\x32\x1b.evm_messages.ArgumentTupleH\x00\x42\x07\n\x05Value\">\n\rArgumentArray\x12-\n\x08\x45lements\x18\x01 \x03(\x0b\x32\x1b.evm_messages.ArgumentValue\"L\n\rArgumentTuple\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12-\n\x08\x45lements\x18\x02 \x03(\x0b\x32\x1b.evm_messages.ArgumentValue\"\xfb\x01\n\x12ParsedAbiSignature\x12\x0e\n\x06Parsed\x18\x01 \x01(\x08\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x11\n\tSignature\x18\x03 \x01(\t\x12\x0b\n\x03\x41\x62i\x18\x04 \x01(\t\x12\x15\n\rSignatureHash\x18\x05 \x01(\x0c\x12<\n\x04Type\x18\x06 \x01(\x0e\x32..evm_messages.ParsedAbiSignature.SignatureType\"R\n\rSignatureType\x12\x0c\n\x08\x46UNCTION\x10\x00\x12\x0f\n\x0b\x43ONSTRUCTOR\x10\x01\x12\x0c\n\x08\x46\x41LLBACK\x10\x02\x12\x0b\n\x07RECEIVE\x10\x03\x12\x07\n\x03LOG\x10\x04\"[\n\x0eParsedArgument\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07Indexed\x18\x02 \x01(\x08\x12*\n\x05Value\x18\x03 \x01(\x0b\x32\x1b.evm_messages.ArgumentValue\"\xbd\x01\n\x12ParsedAbiLogHeader\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x12\n\nEnterIndex\x18\x02 \x01(\r\x12\x11\n\tExitIndex\x18\x03 \x01(\r\x12\x19\n\x11LogAfterCallIndex\x18\x04 \x01(\r\x12\n\n\x02Pc\x18\x05 \x01(\x04\x12\x15\n\rSmartContract\x18\x06 \x01(\x0c\x12\x33\n\tSignature\x18\x07 \x01(\x0b\x32 .evm_messages.ParsedAbiSignature\"\xbf\x01\n\x0cParsedAbiLog\x12\'\n\x06Header\x18\x01 \x01(\x0b\x32\x17.evm_messages.LogHeader\x12#\n\x06Topics\x18\x02 \x03(\x0b\x32\x13.evm_messages.Topic\x12\x30\n\x06Parsed\x18\x03 \x01(\x0b\x32 .evm_messages.ParsedAbiLogHeader\x12/\n\tArguments\x18\x04 \x03(\x0b\x32\x1c.evm_messages.ParsedArgument\"\x96\x01\n\x11ParsedStateChange\x12\x12\n\nEnterIndex\x18\x01 \x01(\r\x12\x11\n\tExitIndex\x18\x02 \x01(\r\x12\x1c\n\x14\x43hangeAfterCallIndex\x18\x03 \x01(\r\x12\n\n\x02Pc\x18\x04 \x01(\x04\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\x0c\x12\x10\n\x08Location\x18\x06 \x01(\x0c\x12\r\n\x05Value\x18\x07 \x01(\x0c\"\xc4\x03\n\x13ParsedAbiCallHeader\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05\x44\x65pth\x18\x02 \x01(\r\x12\x12\n\nEnterIndex\x18\x03 \x01(\r\x12\x11\n\tExitIndex\x18\x04 \x01(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x05 \x01(\x05\x12\x15\n\rInternalCalls\x18\x06 \x01(\r\x12\x10\n\x08\x43\x61llPath\x18\x07 \x03(\r\x12\x0c\n\x04\x46rom\x18\x08 \x01(\x0c\x12\n\n\x02To\x18\t \x01(\x0c\x12\x0e\n\x06\x43reate\x18\n \x01(\x08\x12\r\n\x05Input\x18\x0b \x01(\x0c\x12\x0b\n\x03Gas\x18\x0c \x01(\x04\x12\r\n\x05Value\x18\r \x01(\x0c\x12\x0e\n\x06Output\x18\x0e \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x0f \x01(\x04\x12\r\n\x05\x45rror\x18\x10 \x01(\t\x12$\n\x06Opcode\x18\x11 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x14\n\x0cSelfDestruct\x18\x12 \x01(\x08\x12\x11\n\tDelegated\x18\x13 \x01(\x08\x12\x0f\n\x07Success\x18\x14 \x01(\x08\x12\x10\n\x08Reverted\x18\x15 \x01(\x08\x12\x33\n\tSignature\x18\x16 \x01(\x0b\x32 .evm_messages.ParsedAbiSignature\"\x88\x02\n\rParsedAbiCall\x12\x31\n\x06Header\x18\x01 \x01(\x0b\x32!.evm_messages.ParsedAbiCallHeader\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.evm_messages.ParsedArgument\x12\x32\n\x0cReturnValues\x18\x03 \x03(\x0b\x32\x1c.evm_messages.ParsedArgument\x12(\n\x04Logs\x18\x04 \x03(\x0b\x32\x1a.evm_messages.ParsedAbiLog\x12\x35\n\x0cStateChanges\x18\x05 \x03(\x0b\x32\x1f.evm_messages.ParsedStateChange\"\xa1\x01\n\x0eTransactionFee\x12\x11\n\tSenderFee\x18\x01 \x01(\x0c\x12\x19\n\x11PriorityFeePerGas\x18\x02 \x01(\x0c\x12\x19\n\x11\x45\x66\x66\x65\x63tiveGasPrice\x18\x03 \x01(\x0c\x12\x11\n\tGasRefund\x18\x04 \x01(\x04\x12\r\n\x05\x42urnt\x18\x05 \x01(\x0c\x12\x0f\n\x07Savings\x18\x06 \x01(\x0c\x12\x13\n\x0bMinerReward\x18\x07 \x01(\x0c\"S\n\x1aParsedAbiTransactionStatus\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x10\n\x08\x45ndError\x18\x02 \x01(\t\x12\x12\n\nFaultError\x18\x03 \x01(\t\"\xd9\x02\n\x14ParsedAbiTransaction\x12:\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\x12\x32\n\rReceiptHeader\x18\x02 \x01(\x0b\x32\x1b.evm_messages.ReceiptHeader\x12\x34\n\x0eTransactionFee\x18\x03 \x01(\x0b\x32\x1c.evm_messages.TransactionFee\x12\x43\n\x11TransactionStatus\x18\x04 \x01(\x0b\x32(.evm_messages.ParsedAbiTransactionStatus\x12*\n\x05\x43\x61lls\x18\x05 \x03(\x0b\x32\x1b.evm_messages.ParsedAbiCall\x12*\n\tSignature\x18\x06 \x01(\x0b\x32\x17.evm_messages.Signature\"\x99\x01\n\x0bMinerReward\x12\r\n\x05Total\x18\x01 \x01(\x0c\x12\x0e\n\x06Static\x18\x02 \x01(\x0c\x12\x0f\n\x07\x44ynamic\x18\x03 \x01(\x0c\x12\x0e\n\x06TxFees\x18\x04 \x01(\x0c\x12\x11\n\tBurntFees\x18\x05 \x01(\x0c\x12\r\n\x05Uncle\x18\x06 \x01(\x0c\x12\x18\n\x0b\x42\x65neficiary\x18\x07 \x01(\x0cH\x00\x88\x01\x01\x42\x0e\n\x0c_Beneficiary\"\x97\x03\n\x15ParsedAbiBlockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12)\n\x06Uncles\x18\x03 \x03(\x0b\x32\x19.evm_messages.BlockHeader\x12)\n\x06Reward\x18\x04 \x01(\x0b\x32\x19.evm_messages.MinerReward\x12/\n\x0cUncleRewards\x18\x05 \x03(\x0b\x32\x19.evm_messages.MinerReward\x12\x38\n\x0cTransactions\x18\x06 \x03(\x0b\x32\".evm_messages.ParsedAbiTransaction\x12\x30\n\x08L1Header\x18\x07 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x12/\n\x0c\x45xtraRewards\x18\x08 \x03(\x0b\x32\x19.evm_messages.MinerRewardB\x0b\n\t_L1Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.parsed_abi_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ARGUMENTVALUE']._serialized_start=78
  _globals['_ARGUMENTVALUE']._serialized_end=308
  _globals['_ARGUMENTARRAY']._serialized_start=310
  _globals['_ARGUMENTARRAY']._serialized_end=372
  _globals['_ARGUMENTTUPLE']._serialized_start=374
  _globals['_ARGUMENTTUPLE']._serialized_end=450
  _globals['_PARSEDABISIGNATURE']._serialized_start=453
  _globals['_PARSEDABISIGNATURE']._serialized_end=704
  _globals['_PARSEDABISIGNATURE_SIGNATURETYPE']._serialized_start=622
  _globals['_PARSEDABISIGNATURE_SIGNATURETYPE']._serialized_end=704
  _globals['_PARSEDARGUMENT']._serialized_start=706
  _globals['_PARSEDARGUMENT']._serialized_end=797
  _globals['_PARSEDABILOGHEADER']._serialized_start=800
  _globals['_PARSEDABILOGHEADER']._serialized_end=989
  _globals['_PARSEDABILOG']._serialized_start=992
  _globals['_PARSEDABILOG']._serialized_end=1183
  _globals['_PARSEDSTATECHANGE']._serialized_start=1186
  _globals['_PARSEDSTATECHANGE']._serialized_end=1336
  _globals['_PARSEDABICALLHEADER']._serialized_start=1339
  _globals['_PARSEDABICALLHEADER']._serialized_end=1791
  _globals['_PARSEDABICALL']._serialized_start=1794
  _globals['_PARSEDABICALL']._serialized_end=2058
  _globals['_TRANSACTIONFEE']._serialized_start=2061
  _globals['_TRANSACTIONFEE']._serialized_end=2222
  _globals['_PARSEDABITRANSACTIONSTATUS']._serialized_start=2224
  _globals['_PARSEDABITRANSACTIONSTATUS']._serialized_end=2307
  _globals['_PARSEDABITRANSACTION']._serialized_start=2310
  _globals['_PARSEDABITRANSACTION']._serialized_end=2655
  _globals['_MINERREWARD']._serialized_start=2658
  _globals['_MINERREWARD']._serialized_end=2811
  _globals['_PARSEDABIBLOCKMESSAGE']._serialized_start=2814
  _globals['_PARSEDABIBLOCKMESSAGE']._serialized_end=3221
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/token_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'evm/token_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65vm/token_block_message.proto\x12\x0c\x65vm_messages\x1a\x17\x65vm/block_message.proto\"\xc3\x01\n\tTokenInfo\x12\x15\n\rSmartContract\x18\x01 \x01(\x0c\x12\x11\n\tDelegated\x18\x02 \x01(\x08\x12\x13\n\x0b\x44\x65legatedTo\x18\x03 \x01(\x0c\x12\x14\n\x0cProtocolName\x18\x04 \x01(\t\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\x0e\n\x06Symbol\x18\x06 \x01(\t\x12\x10\n\x08\x44\x65\x63imals\x18\x07 \x01(\x05\x12\x0e\n\x06HasURI\x18\x08 \x01(\x08\x12\x10\n\x08\x46ungible\x18\t \x01(\x08\x12\x0f\n\x07\x41ssetId\x18\n \x01(\t\"\xb2\x02\n\rTokenTransfer\x12\x1c\n\x10TransactionIndex\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x11\n\tCallIndex\x18\x02 \x01(\x04\x12\x10\n\x08LogIndex\x18\x03 \x01(\x04\x12\x0e\n\x06Sender\x18\x04 \x01(\x0c\x12\x10\n\x08Receiver\x18\x05 \x01(\x0c\x12\x0e\n\x06\x41mount\x18\x06 \x01(\x0c\x12\n\n\x02Id\x18\x07 \x01(\x0c\x12\x0b\n\x03URI\x18\x08 \x01(\t\x12)\n\x08\x43urrency\x18\t \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12\x0f\n\x07Success\x18\n \x01(\x08\x12\x0c\n\x04\x44\x61ta\x18\x0c \x01(\x0c\x12\r\n\x05Index\x18\r \x01(\r\x12:\n\x11TransactionHeader\x18\x0e \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\"\xd1\x01\n\x11TokenBlockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12.\n\tTransfers\x18\x05 \x03(\x0b\x32\x1b.evm_messages.TokenTransfer\x12\x30\n\x08L1Header\x18\x06 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x42\x0b\n\t_L1Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.token_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENTRANSFER'].fields_by_name['TransactionIndex']._loaded_options = None
  _globals['_TOKENTRANSFER'].fields_by_name['TransactionIndex']._serialized_options = b'\030\001'
  _globals['_TOKENINFO']._serialized_start=73
  _globals['_TOKENINFO']._serialized_end=268
  _globals['_TOKENTRANSFER']._serialized_start=271
  _globals['_TOKENTRANSFER']._serialized_end=577
  _globals['_TOKENBLOCKMESSAGE']._serialized_start=580
  _globals['_TOKENBLOCKMESSAGE']._serialized_end=789
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: price_index.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'price_index.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import marketdata_pb2 as marketdata__pb2



DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11price_index.proto\x12\x0bprice_index\x1a\x10marketdata.proto\"4\n\x08\x43urrency\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06Symbol\x18\x03 \x01(\t\"\x93\x01\n\x06Market\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0f\n\x07Network\x18\x02 \x01(\t\x12\x12\n\nNetworkBid\x18\x03 \x01(\t\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\x12\x10\n\x08Protocol\x18\x06 \x01(\t\x12\x16\n\x0eProtocolFamily\x18\x07 \x01(\t\x12\x0f\n\x07Program\x18\x08 \x01(\t\"P\n\x07\x41mounts\x12\x0c\n\x04\x42\x61se\x18\x01 \x01(\x02\x12\r\n\x05Quote\x18\x02 \x01(\x02\x12\x0b\n\x03Usd\x18\x03 \x01(\x02\x12\x1b\n\x13\x42\x61seAttributedToUsd\x18\x04 \x01(\x02\"\\\n\x05Quote\x12,\n\rQuoteCurrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12%\n\x07\x41mounts\x18\x02 \x01(\x0b\x32\x14.price_index.Amounts\"<\n\x0cTimeInterval\x12\x10\n\x08\x44uration\x18\x01 \x01(\r\x12\r\n\x05Start\x18\x02 \x01(\r\x12\x0b\n\x03\x45nd\x18\x03 \x01(\r\"N\n\x04Ohlc\x12\x0c\n\x04Open\x18\x01 \x01(\x02\x12\r\n\x05\x43lose\x18\x02 \x01(\x02\x12\x0c\n\x04High\x18\x03 \x01(\x02\x12\x0b\n\x03Low\x18\x04 \x01(\x02\x12\x0e\n\x06Volume\x18\x05 \x01(\x02\"\x85\x02\n\x13PriceByTimeInterval\x12/\n\x0cTimeInterval\x18\x01 \x01(\x0b\x32\x19.price_index.TimeInterval\x12%\n\x07\x41mounts\x18\x02 \x01(\x0b\x32\x14.price_index.Amounts\x12\x11\n\tMeanPrice\x18\x03 \x01(\x02\x12\x1b\n\x13SimpleMovingAverage\x18\x04 \x01(\x02\x12#\n\x1bWeightedSimpleMovingAverage\x18\x05 \x01(\x02\x12 \n\x18\x45xponentialMovingAverage\x18\x06 \x01(\x02\x12\x1f\n\x04Ohlc\x18\x07 \x01(\x0b\x32\x11.price_index.Ohlc\"\x90\x01\n\rPriceByVolume\x12\x14\n\x0cTargetVolume\x18\x01 \x01(\x02\x12/\n\x0cTimeInterval\x18\x02 \x01(\x0b\x32\x19.price_index.TimeInterval\x12%\n\x07\x41mounts\x18\x03 \x01(\x0b\x32\x14.price_index.Amounts\x12\x11\n\tMeanPrice\x18\x04 \x01(\x02\"(\n\x0f\x45stimatedPrices\x12\x15\n\rAdaptivePrice\x18\x01 \x01(\x02\"\xd6\x01\n\x0bPriceUpdate\x12\"\n\x06Quotes\x18\x01 \x03(\x0b\x32\x12.price_index.Quote\x12>\n\x14PriceByTimeIntervals\x18\x02 \x03(\x0b\x32 .price_index.PriceByTimeInterval\x12\x32\n\x0ePriceByVolumes\x18\x03 \x03(\x0b\x32\x1a.price_index.PriceByVolume\x12/\n\tEstimates\x18\x04 \x01(\x0b\x32\x1c.price_index.EstimatedPrices\"h\n\x0e\x43urrencyUpdate\x12\'\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12-\n\x0bPriceUpdate\x18\x02 \x01(\x0b\x32\x18.price_index.PriceUpdate\"\x88\x01\n\x0bTokenUpdate\x12\'\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12!\n\x05Token\x18\x02 \x01(\x0b\x32\x12.price_index.Token\x12-\n\x0bPriceUpdate\x18\x03 \x01(\x0b\x32\x18.price_index.PriceUpdate\"\xbe\x02\n\nPairUpdate\x12\'\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12,\n\rQuoteCurrency\x18\x02 \x01(\x0b\x32\x15.price_index.Currency\x12!\n\x05Token\x18\x03 \x01(\x0b\x32\x12.price_index.Token\x12&\n\nQuoteToken\x18\x04 \x01(\x0b\x32\x12.price_index.Token\x12#\n\x06Market\x18\x05 \x01(\x0b\x32\x13.price_index.Market\x12-\n\x0bPriceUpdate\x18\x06 \x01(\x0b\x32\x18.price_index.PriceUpdate\x12:\n\x18PriceUpdateInQuoteTokens\x18\x07 \x01(\x0b\x32\x18.price_index.PriceUpdate\"\xb5\x01\n\x11PriceIndexMessage\x12\x0c\n\x04Time\x18\x01 \x01(\x04\x12\x34\n\x0f\x43urrencyUpdates\x18\x02 \x03(\x0b\x32\x1b.price_index.CurrencyUpdate\x12.\n\x0cTokenUpdates\x18\x03 \x03(\x0b\x32\x18.price_index.TokenUpdate\x12,\n\x0bPairUpdates\x18\x04 \x03(\x0b\x32\x17.price_index.PairUpdateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'price_index_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CURRENCY']._serialized_start=52
  _globals['_CURRENCY']._serialized_end=104
  _globals['_MARKET']._serialized_start=107
  _globals['_MARKET']._serialized_end=254
  _globals['_AMOUNTS']._serialized_start=256
  _globals['_AMOUNTS']._serialized_end=336
  _globals['_QUOTE']._serialized_start=338
  _globals['_QUOTE']._serialized_end=430
  _globals['_TIMEINTERVAL']._serialized_start=432
  _globals['_TIMEINTERVAL']._serialized_end=492
  _globals['_OHLC']._serialized_start=494
  _globals['_OHLC']._serialized_end=572
  _globals['_PRICEBYTIMEINTERVAL']._serialized_start=575
  _globals['_PRICEBYTIMEINTERVAL']._serialized_end=836
  _globals['_PRICEBYVOLUME']._serialized_start=839
  _globals['_PRICEBYVOLUME']._serialized_end=983
  _globals['_ESTIMATEDPRICES']._serialized_start=985
  _globals['_ESTIMATEDPRICES']._serialized_end=1025
  _globals['_PRICEUPDATE']._serialized_start=1028
  _globals['_PRICEUPDATE']._serialized_end=1242
  _globals['_CURRENCYUPDATE']._serialized_start=1244
  _globals['_CURRENCYUPDATE']._serialized_end=1348
  _globals['_TOKENUPDATE']._serialized_start=1351
  _globals['_TOKENUPDATE']._serialized_end=1487
  _globals['_PAIRUPDATE']._serialized_start=1490
  _globals['_PAIRUPDATE']._serialized_end=1808
  _globals['_PRICEINDEXMESSAGE']._serialized_start=1811
  _globals['_PRICEINDEXMESSAGE']._serialized_end=1992
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/ohlc_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'solana/ohlc_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import token_block_message_pb2 as solana_dot_token__block__message__pb2
from solana import dex_block_message_pb2 as solana_dot_dex__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19solana/ohlc_message.proto\x12\x0fsolana_messages\x1a solana/token_block_message.proto\x1a\x1esolana/dex_block_message.proto\"N\n\x0eOhlcDescriptor\x12\x12\n\nPeriodMsec\x18\x01 \x01(\x05\x12\x11\n\tDelayMsec\x18\x02 \x01(\x05\x12\x15\n\rTimestampMsec\x18\x03 \x01(\x03\"e\n\x13OhlcPairTradeAmount\x12\x12\n\nBaseAmount\x18\x01 \x01(\x04\x12\x13\n\x0bQuoteAmount\x18\x02 \x01(\x04\x12%\n\x03\x44\x65x\x18\x03 \x01(\x0b\x32\x18.solana_messages.DexInfo\"\xf4\x01\n\x08OhlcPair\x12\'\n\x04\x42\x61se\x18\x01 \x01(\x0b\x32\x19.solana_messages.Currency\x12(\n\x05Quote\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\x12\x12\n\nBaseAmount\x18\x03 \x01(\x04\x12\x13\n\x0bQuoteAmount\x18\x04 \x01(\x04\x12\x0c\n\x04High\x18\x05 \x01(\x02\x12\x0b\n\x03Low\x18\x06 \x01(\x02\x12\x0c\n\x04Open\x18\x07 \x01(\x02\x12\r\n\x05\x43lose\x18\x08 \x01(\x02\x12\x34\n\x06Trades\x18\t \x03(\x0b\x32$.solana_messages.OhlcPairTradeAmount\"k\n\x0bOhlcMessage\x12\x33\n\nDescriptor\x18\x01 \x01(\x0b\x32\x1f.solana_messages.OhlcDescriptor\x12\'\n\x04Pair\x18\x02 \x03(\x0b\x32\x19.solana_messages.OhlcPairb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.ohlc_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_OHLCDESCRIPTOR']._serialized_start=112
  _globals['_OHLCDESCRIPTOR']._serialized_end=190
  _globals['_OHLCPAIRTRADEAMOUNT']._serialized_start=192
  _globals['_OHLCPAIRTRADEAMOUNT']._serialized_end=293
  _globals['_OHLCPAIR']._serialized_start=296
  _globals['_OHLCPAIR']._serialized_end=540
  _globals['_OHLCMESSAGE']._serialized_start=542
  _globals['_OHLCMESSAGE']._serialized_end=649
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'evm/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65vm/block_message.proto\x12\x0c\x65vm_messages\";\n\x0b\x41\x64\x64ressCode\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x0c\n\x04Size\x18\x02 \x01(\x05\x12\x10\n\x08Suicided\x18\x03 \x01(\x08\"\xdf\x03\n\x0b\x42lockHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x12\n\nParentHash\x18\x02 \x01(\x0c\x12\x11\n\tUncleHash\x18\x03 \x01(\x0c\x12\x0c\n\x04Root\x18\x04 \x01(\x0c\x12\x0e\n\x06TxHash\x18\x05 \x01(\x0c\x12\x13\n\x0bReceiptHash\x18\x06 \x01(\x0c\x12\x11\n\tMixDigest\x18\x07 \x01(\x0c\x12\x10\n\x08\x43oinbase\x18\x08 \x01(\x0c\x12\r\n\x05\x42loom\x18\t \x01(\x0c\x12\r\n\x05\x45xtra\x18\n \x01(\x0c\x12\r\n\x05Nonce\x18\x0b \x01(\x04\x12\x12\n\nDifficulty\x18\x0c \x01(\x0c\x12\x0e\n\x06Number\x18\r \x01(\x0c\x12\x10\n\x08GasLimit\x18\x0e \x01(\x04\x12\x0f\n\x07GasUsed\x18\x0f \x01(\x04\x12\x0c\n\x04Time\x18\x10 \x01(\x04\x12\x0f\n\x07\x42\x61seFee\x18\x11 \x01(\x0c\x12\x1b\n\x0eSequenceNumber\x18\x12 \x01(\x04H\x00\x88\x01\x01\x12\x18\n\x0b\x42\x61tcherAddr\x18\x13 \x01(\x0cH\x01\x88\x01\x01\x12\x1a\n\rL1FeeOverhead\x18\x14 \x01(\x0cH\x02\x88\x01\x01\x12\x18\n\x0bL1FeeScalar\x18\x15 \x01(\x0cH\x03\x88\x01\x01\x42\x11\n\x0f_SequenceNumberB\x0e\n\x0c_BatcherAddrB\x10\n\x0e_L1FeeOverheadB\x0e\n\x0c_L1FeeScalar\"*\n\x0b\x42lockResult\x12\x0b\n\x03Gas\x18\x01 \x01(\x04\x12\x0e\n\x06\x45rrors\x18\x02 \x01(\t\",\n\tSignature\x12\t\n\x01R\x18\x01 \x01(\x0c\x12\t\n\x01V\x18\x02 \x01(\x0c\x12\t\n\x01S\x18\x03 \x01(\x0c\"$\n\x05Topic\x12\r\n\x05Index\x18\x01 \x01(\x04\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\"\x9e\x01\n\tLogHeader\x12\r\n\x05Index\x18\x01 \x01(\x04\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\x12\x0f\n\x07Removed\x18\x04 \x01(\x08\x12.\n\x0b\x41\x64\x64ressCode\x18\x05 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x15\n\x08IsSystem\x18\x06 \x01(\x08H\x00\x88\x01\x01\x42\x0b\n\t_IsSystem\"V\n\x03Log\x12*\n\tLogHeader\x18\x01 \x01(\x0b\x32\x17.evm_messages.LogHeader\x12#\n\x06Topics\x18\x02 \x03(\x0b\x32\x13.evm_messages.Topic\"9\n\x05Store\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x10\n\x08Location\x18\x02 \x01(\x0c\x12\r\n\x05Value\x18\x03 \x01(\x0c\"\x92\x03\n\rReceiptHeader\x12\r\n\x05\x42loom\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x04\x12\x0c\n\x04Type\x18\x03 \x01(\r\x12\x17\n\x0f\x43ontractAddress\x18\x04 \x01(\x0c\x12\x19\n\x11\x43umulativeGasUsed\x18\x05 \x01(\x04\x12\x11\n\tPostState\x18\x06 \x01(\x0c\x12\x0e\n\x06Status\x18\x07 \x01(\x04\x12\x36\n\x13\x43ontractAddressCode\x18\x08 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x31\n\x02L1\x18\t \x01(\x0b\x32 .evm_messages.ReceiptL1ExtensionH\x00\x88\x01\x01\x12\x1e\n\x11\x45\x66\x66\x65\x63tiveGasPrice\x18\n \x01(\x0cH\x01\x88\x01\x01\x12\x18\n\x0b\x42lobGasUsed\x18\x0b \x01(\x04H\x02\x88\x01\x01\x12\x19\n\x0c\x42lobGasPrice\x18\x0c \x01(\x0cH\x03\x88\x01\x01\x42\x05\n\x03_L1B\x14\n\x12_EffectiveGasPriceB\x0e\n\x0c_BlobGasUsedB\x0f\n\r_BlobGasPrice\"D\n\x12ReceiptL1Extension\x12\x10\n\x08GasPrice\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x0c\x12\x0b\n\x03\x46\x65\x65\x18\x03 \x01(\x0c\"^\n\x07Receipt\x12\x32\n\rReceiptHeader\x18\x01 \x01(\x0b\x32\x1b.evm_messages.ReceiptHeader\x12\x1f\n\x04Logs\x18\x02 \x03(\x0b\x32\x11.evm_messages.Log\"$\n\x06Opcode\x12\x0c\n\x04\x43ode\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\"\xb0\x01\n\x0c\x43\x61ptureStart\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x0c\x12\n\n\x02To\x18\x02 \x01(\x0c\x12\x0e\n\x06\x43reate\x18\x03 \x01(\x08\x12\r\n\x05Input\x18\x04 \x01(\x0c\x12\x0b\n\x03Gas\x18\x05 \x01(\x04\x12\r\n\x05Value\x18\x06 \x01(\x0c\x12)\n\x06ToCode\x18\x07 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x14\n\x07TokenId\x18\x08 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_TokenId\"<\n\nCaptureEnd\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x04\x12\r\n\x05\x45rror\x18\x03 \x01(\t\"r\n\x08\x43ontract\x12\x15\n\rCallerAddress\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43\x61ller\x18\x02 \x01(\x0c\x12\x0f\n\x07\x41\x64\x64ress\x18\x03 \x01(\x0c\x12\x10\n\x08\x43odeAddr\x18\x04 \x01(\x0c\x12\r\n\x05Input\x18\x05 \x01(\x0c\x12\r\n\x05Value\x18\x06 \x01(\x0c\"\xc2\x01\n\x0c\x43\x61ptureFault\x12\n\n\x02Pc\x18\x01 \x01(\x04\x12$\n\x06Opcode\x18\x02 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x0b\n\x03Gas\x18\x03 \x01(\x04\x12\x0c\n\x04\x43ost\x18\x04 \x01(\x04\x12\x0e\n\x06Memory\x18\x05 \x01(\x0c\x12\r\n\x05\x44\x65pth\x18\x06 \x01(\x04\x12\r\n\x05Stack\x18\x07 \x03(\x0c\x12(\n\x08\x43ontract\x18\x08 \x01(\x0b\x32\x16.evm_messages.Contract\x12\r\n\x05\x45rror\x18\t \x01(\t\"\xc6\x01\n\x0c\x43\x61ptureEnter\x12$\n\x06Opcode\x18\x01 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x0c\n\x04\x46rom\x18\x02 \x01(\x0c\x12\n\n\x02To\x18\x03 \x01(\x0c\x12\r\n\x05Input\x18\x04 \x01(\x0c\x12\x0b\n\x03Gas\x18\x05 \x01(\x04\x12\r\n\x05Value\x18\x06 \x01(\x0c\x12)\n\x06ToCode\x18\x07 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x14\n\x07TokenId\x18\x08 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_TokenId\"=\n\x0b\x43\x61ptureExit\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x04\x12\r\n\x05\x45rror\x18\x03 \x01(\t\"\xd3\x01\n\x12\x43\x61ptureStateHeader\x12\x12\n\nEnterIndex\x18\x01 \x01(\r\x12\x11\n\tExitIndex\x18\x02 \x01(\r\x12\n\n\x02Pc\x18\x03 \x01(\x04\x12$\n\x06Opcode\x18\x04 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x0b\n\x03Gas\x18\x05 \x01(\x04\x12\x0c\n\x04\x43ost\x18\x06 \x01(\x04\x12\r\n\x05RData\x18\x07 \x01(\x0c\x12\r\n\x05\x44\x65pth\x18\x08 \x01(\x04\x12\r\n\x05\x45rror\x18\t \x01(\t\x12\x12\n\x05Index\x18\n \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_Index\"\x90\x01\n\x0c\x43\x61ptureState\x12<\n\x12\x43\x61ptureStateHeader\x18\x01 \x01(\x0b\x32 .evm_messages.CaptureStateHeader\x12\x1e\n\x03Log\x18\x02 \x01(\x0b\x32\x11.evm_messages.Log\x12\"\n\x05Store\x18\x03 \x01(\x0b\x32\x13.evm_messages.Store\"\xf5\x01\n\x04\x43\x61ll\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05\x44\x65pth\x18\x02 \x01(\r\x12\x12\n\nEnterIndex\x18\x03 \x01(\r\x12\x11\n\tExitIndex\x18\x04 \x01(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x05 \x01(\x05\x12\x30\n\x0c\x43\x61ptureEnter\x18\x06 \x01(\x0b\x32\x1a.evm_messages.CaptureEnter\x12.\n\x0b\x43\x61ptureExit\x18\x07 \x01(\x0b\x32\x19.evm_messages.CaptureExit\x12\x31\n\rCaptureStates\x18\x08 \x03(\x0b\x32\x1a.evm_messages.CaptureState\"\xef\x01\n\x05Trace\x12!\n\x05\x43\x61lls\x18\x01 \x03(\x0b\x32\x12.evm_messages.Call\x12\x30\n\x0c\x43\x61ptureStart\x18\x02 \x01(\x0b\x32\x1a.evm_messages.CaptureStart\x12,\n\nCaptureEnd\x18\x03 \x01(\x0b\x32\x18.evm_messages.CaptureEnd\x12\x30\n\x0c\x43\x61ptureFault\x18\x04 \x01(\x0b\x32\x1a.evm_messages.CaptureFault\x12\x31\n\rCaptureStates\x18\x05 \x03(\x0b\x32\x1a.evm_messages.CaptureState\"3\n\x0b\x41\x63\x63\x65ssTuple\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x13\n\x0bStorageKeys\x18\x02 \x03(\x0c\"\xbf\x04\n\x11TransactionHeader\x12\r\n\x05Index\x18\x01 \x01(\x04\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\x12\x0b\n\x03Gas\x18\x03 \x01(\x04\x12\r\n\x05Value\x18\x04 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\r\n\x05Nonce\x18\x06 \x01(\x04\x12\x0f\n\x07\x43hainId\x18\x07 \x01(\x0c\x12\x0c\n\x04\x43ost\x18\x08 \x01(\x0c\x12\x11\n\tGasFeeCap\x18\t \x01(\x0c\x12\x10\n\x08GasPrice\x18\n \x01(\x0c\x12\x11\n\tGasTipCap\x18\x0b \x01(\x0c\x12\x11\n\tProtected\x18\x0c \x01(\x08\x12\x0c\n\x04Type\x18\r \x01(\r\x12\n\n\x02To\x18\x0e \x01(\x0c\x12\x0c\n\x04\x46rom\x18\x0f \x01(\x0c\x12)\n\x06ToCode\x18\x10 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12-\n\nAccessList\x18\x11 \x03(\x0b\x32\x19.evm_messages.AccessTuple\x12\x12\n\x05GasL1\x18\x12 \x01(\x04H\x00\x88\x01\x01\x12\x17\n\nIsSystemTx\x18\x13 \x01(\x08H\x01\x88\x01\x01\x12\x1b\n\x0e\x45\x66\x66\x65\x63tiveNonce\x18\x14 \x01(\x04H\x02\x88\x01\x01\x12\x17\n\nSourceHash\x18\x15 \x01(\x0cH\x03\x88\x01\x01\x12\x11\n\x04Time\x18\x16 \x01(\x04H\x04\x88\x01\x01\x12%\n\x04\x42lob\x18\x17 \x01(\x0b\x32\x12.evm_messages.BlobH\x05\x88\x01\x01\x42\x08\n\x06_GasL1B\r\n\x0b_IsSystemTxB\x11\n\x0f_EffectiveNonceB\r\n\x0b_SourceHashB\x07\n\x05_TimeB\x07\n\x05_Blob\"c\n\x04\x42lob\x12\x0e\n\x06Hashes\x18\x01 \x03(\x0c\x12\x0e\n\x06Proofs\x18\x02 \x03(\x0c\x12\x13\n\x0b\x43ommitments\x18\x03 \x03(\x0c\x12\x0f\n\x07\x42lobGas\x18\x04 \x01(\x04\x12\x15\n\rBlobGasFeeCap\x18\x05 \x01(\x0c\"\xd3\x01\n\x0bTransaction\x12:\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\x12*\n\tSignature\x18\x02 \x01(\x0b\x32\x17.evm_messages.Signature\x12&\n\x07Receipt\x18\x03 \x01(\x0b\x32\x15.evm_messages.Receipt\x12\"\n\x05Trace\x18\x04 \x01(\x0b\x32\x13.evm_messages.Trace\x12\x10\n\x04Time\x18\x05 \x01(\x04\x42\x02\x18\x01\"(\n\x05\x43hain\x12\x0f\n\x07\x43hainId\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43onfig\x18\x02 \x01(\t\"\xa1\x01\n\rL1MessageInfo\x12\x0c\n\x04Kind\x18\x01 \x01(\r\x12\x0e\n\x06Poster\x18\x02 \x01(\x0c\x12\x13\n\x0b\x42lockNumber\x18\x03 \x01(\x04\x12\x11\n\tTimestamp\x18\x04 \x01(\x04\x12\x16\n\tRequestId\x18\x05 \x01(\x0cH\x00\x88\x01\x01\x12\x16\n\tL1BaseFee\x18\x06 \x01(\x0cH\x01\x88\x01\x01\x42\x0c\n\n_RequestIdB\x0c\n\n_L1BaseFee\"\xee\x02\n\x0c\x42lockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12)\n\x06Result\x18\x03 \x01(\x0b\x32\x19.evm_messages.BlockResult\x12)\n\x06Uncles\x18\x04 \x03(\x0b\x32\x19.evm_messages.BlockHeader\x12/\n\x0cTransactions\x18\x05 \x03(\x0b\x32\x19.evm_messages.Transaction\x12\x30\n\x08L1Header\x18\x06 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x12\x37\n\rL1MessageInfo\x18\x07 \x01(\x0b\x32\x1b.evm_messages.L1MessageInfoH\x01\x88\x01\x01\x42\x0b\n\t_L1HeaderB\x10\n\x0e_L1MessageInfoB \n\x12io.bitquery.protosB\nEvmMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.bitquery.protosB\nEvmMessage'
  _globals['_TRANSACTION'].fields_by_name['Time']._loaded_options = None
  _globals['_TRANSACTION'].fields_by_name['Time']._serialized_options = b'\030\001'
  _globals['_ADDRESSCODE']._serialized_start=41
  _globals['_ADDRESSCODE']._serialized_end=100
  _globals['_BLOCKHEADER']._serialized_start=103
  _globals['_BLOCKHEADER']._serialized_end=582
  _globals['_BLOCKRESULT']._serialized_start=584
  _globals['_BLOCKRESULT']._serialized_end=626
  _globals['_SIGNATURE']._serialized_start=628
  _globals['_SIGNATURE']._serialized_end=672
  _globals['_TOPIC']._serialized_start=674
  _globals['_TOPIC']._serialized_end=710
  _globals['_LOGHEADER']._serialized_start=713
  _globals['_LOGHEADER']._serialized_end=871
  _globals['_LOG']._serialized_start=873
  _globals['_LOG']._serialized_end=959
  _globals['_STORE']._serialized_start=961
  _globals['_STORE']._serialized_end=1018
  _globals['_RECEIPTHEADER']._serialized_start=1021
  _globals['_RECEIPTHEADER']._serialized_end=1423
  _globals['_RECEIPTL1EXTENSION']._serialized_start=1425
  _globals['_RECEIPTL1EXTENSION']._serialized_end=1493
  _globals['_RECEIPT']._serialized_start=1495
  _globals['_RECEIPT']._serialized_end=1589
  _globals['_OPCODE']._serialized_start=1591
  _globals['_OPCODE']._serialized_end=1627
  _globals['_CAPTURESTART']._serialized_start=1630
  _globals['_CAPTURESTART']._serialized_end=1806
  _globals['_CAPTUREEND']._serialized_start=1808
  _globals['_CAPTUREEND']._serialized_end=1868
  _globals['_CONTRACT']._serialized_start=1870
  _globals['_CONTRACT']._serialized_end=1984
  _globals['_CAPTUREFAULT']._serialized_start=1987
  _globals['_CAPTUREFAULT']._serialized_end=2181
  _globals['_CAPTUREENTER']._serialized_start=2184
  _globals['_CAPTUREENTER']._serialized_end=2382
  _globals['_CAPTUREEXIT']._serialized_start=2384
  _globals['_CAPTUREEXIT']._serialized_end=2445
  _globals['_CAPTURESTATEHEADER']._serialized_start=2448
  _globals['_CAPTURESTATEHEADER']._serialized_end=2659
  _globals['_CAPTURESTATE']._serialized_start=2662
  _globals['_CAPTURESTATE']._serialized_end=2806
  _globals['_CALL']._serialized_start=2809
  _globals['_CALL']._serialized_end=3054
  _globals['_TRACE']._serialized_start=3057
  _globals['_TRACE']._serialized_end=3296
  _globals['_ACCESSTUPLE']._serialized_start=3298
  _globals['_ACCESSTUPLE']._serialized_end=3349
  _globals['_TRANSACTIONHEADER']._serialized_start=3352
  _globals['_TRANSACTIONHEADER']._serialized_end=3927
  _globals['_BLOB']._serialized_start=3929
  _globals['_BLOB']._serialized_end=4028
  _globals['_TRANSACTION']._serialized_start=4031
  _globals['_TRANSACTION']._serialized_end=4242
  _globals['_CHAIN']._serialized_start=4244
  _globals['_CHAIN']._serialized_end=4284
  _globals['_L1MESSAGEINFO']._serialized_start=4287
  _globals['_L1MESSAGEINFO']._serialized_end=4448
  _globals['_BLOCKMESSAGE']._serialized_start=4451
  _globals['_BLOCKMESSAGE']._serialized_end=4817
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/token_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/token_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import block_message_pb2 as solana_dot_block__message__pb2
from solana import parsed_idl_block_message_pb2 as solana_dot_parsed__idl__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n solana/token_block_message.proto\x12\x0fsolana_messages\x1a\x1asolana/block_message.proto\x1a%solana/parsed_idl_block_message.proto\"@\n\x0cTokenCreator\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x10\n\x08Verified\x18\x02 \x01(\x08\x12\r\n\x05Share\x18\x03 \x01(\r\"\xbb\x04\n\x08\x43urrency\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08\x44\x65\x63imals\x18\x02 \x01(\r\x12\x0b\n\x03Uri\x18\x03 \x01(\t\x12\x0e\n\x06Symbol\x18\x04 \x01(\t\x12\x0e\n\x06Native\x18\x05 \x01(\x08\x12\x0f\n\x07Wrapped\x18\x06 \x01(\x08\x12\x10\n\x08\x46ungible\x18\x07 \x01(\x08\x12\x0b\n\x03Key\x18\x08 \x01(\t\x12\x1c\n\x14SellerFeeBasisPoints\x18\t \x01(\r\x12\x19\n\x0c\x45\x64itionNonce\x18\n \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rTokenStandard\x18\x0b \x01(\tH\x01\x88\x01\x01\x12\x16\n\x0eProgramAddress\x18\x0c \x01(\x0c\x12\x13\n\x0bMintAddress\x18\r \x01(\x0c\x12\x17\n\x0fMetadataAddress\x18\x0e \x01(\x0c\x12\x17\n\x0fUpdateAuthority\x18\x0f \x01(\x0c\x12\x19\n\x11\x43ollectionAddress\x18\x10 \x01(\x0c\x12\x1a\n\x12VerifiedCollection\x18\x11 \x01(\x08\x12\x1b\n\x13PrimarySaleHappened\x18\x12 \x01(\x08\x12\x11\n\tIsMutable\x18\x13 \x01(\x08\x12\x34\n\rTokenCreators\x18\x14 \x03(\x0b\x32\x1d.solana_messages.TokenCreator\x12\x17\n\x0f\x46reezeAuthority\x18\x15 \x01(\x0c\x12\x15\n\rMintAuthority\x18\x16 \x01(\x0c\x12\x0e\n\x06Parsed\x18\x17 \x01(\x08\x42\x0f\n\r_EditionNonceB\x10\n\x0e_TokenStandard\"{\n\x15\x43urrencyBalanceUpdate\x12\x35\n\rBalanceUpdate\x18\x01 \x01(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12+\n\x08\x43urrency\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\"\xa0\x02\n\x08Transfer\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x04\x12(\n\x06Sender\x18\x03 \x01(\x0b\x32\x18.solana_messages.Account\x12*\n\x08Receiver\x18\x04 \x01(\x0b\x32\x18.solana_messages.Account\x12+\n\tAuthority\x18\x05 \x01(\x0b\x32\x18.solana_messages.Account\x12+\n\x08\x43urrency\x18\x06 \x01(\x0b\x32\x19.solana_messages.Currency\x12:\n\x0bInstruction\x18\x07 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xcc\x02\n\x18InstructionBalanceUpdate\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12K\n\x1bTotalCurrencyBalanceUpdates\x18\x02 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12I\n\x19OwnCurrencyBalanceUpdates\x18\x03 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12\x42\n\x12TokenSupplyUpdates\x18\x04 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12:\n\x0bInstruction\x18\x05 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xde\x02\n\x16ParsedTokenTransaction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12,\n\tTransfers\x18\x05 \x03(\x0b\x32\x19.solana_messages.Transfer\x12>\n\x0e\x42\x61lanceUpdates\x18\x06 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12L\n\x19InstructionBalanceUpdates\x18\x07 \x03(\x0b\x32).solana_messages.InstructionBalanceUpdate\"\x80\x01\n\x11TokenBlockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12=\n\x0cTransactions\x18\x02 \x03(\x0b\x32\'.solana_messages.ParsedTokenTransactionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.token_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENCREATOR']._serialized_start=120
  _globals['_TOKENCREATOR']._serialized_end=184
  _globals['_CURRENCY']._serialized_start=187
  _globals['_CURRENCY']._serialized_end=758
  _globals['_CURRENCYBALANCEUPDATE']._serialized_start=760
  _globals['_CURRENCYBALANCEUPDATE']._serialized_end=883
  _globals['_TRANSFER']._serialized_start=886
  _globals['_TRANSFER']._serialized_end=1174
  _globals['_INSTRUCTIONBALANCEUPDATE']._serialized_start=1177
  _globals['_INSTRUCTIONBALANCEUPDATE']._serialized_end=1509
  _globals['_PARSEDTOKENTRANSACTION']._serialized_start=1512
  _globals['_PARSEDTOKENTRANSACTION']._serialized_end=1862
  _globals['_TOKENBLOCKMESSAGE']._serialized_start=1865
  _globals['_TOKENBLOCKMESSAGE']._serialized_end=1993
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: marketdata.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'marketdata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10marketdata.proto\x12\x0bprice_index\"Y\n\x11MarketdataMessage\x12\x34\n\nCurrencies\x18\x01 \x03(\x0b\x32 .price_index.CurrencyPriceBucket\x12\x0e\n\x06Source\x18\x02 \x01(\t\"\xb9\x01\n\x05Token\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0b\n\x03\x44id\x18\x02 \x01(\t\x12\x0f\n\x07Network\x18\x03 \x01(\t\x12\x14\n\x07\x41\x64\x64ress\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07TokenId\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x08IsNative\x18\x06 \x01(\x08\x12\x0c\n\x04Name\x18\x07 \x01(\t\x12\x0e\n\x06Symbol\x18\x08 \x01(\t\x12\x12\n\nNetworkBid\x18\t \x01(\tB\n\n\x08_AddressB\n\n\x08_TokenId\"\x95\x01\n\x13\x43urrencyPriceBucket\x12\"\n\x06Tokens\x18\x01 \x03(\x0b\x32\x12.price_index.Token\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06Symbol\x18\x03 \x01(\t\x12\x12\n\nOriginalId\x18\x04 \x01(\t\x12(\n\x06\x42ucket\x18\x06 \x01(\x0b\x32\x18.price_index.PriceBucket\"\"\n\x05Price\x12\x0c\n\x04Time\x18\x01 \x01(\x04\x12\x0b\n\x03Usd\x18\x02 \x01(\x01\"Z\n\x0bPriceBucket\x12\x10\n\x08Interval\x18\x01 \x01(\r\x12\"\n\x06Prices\x18\x02 \x03(\x0b\x32\x12.price_index.Price\x12\x15\n\rLastUpdatedAt\x18\x03 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'marketdata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MARKETDATAMESSAGE']._serialized_start=33
  _globals['_MARKETDATAMESSAGE']._serialized_end=122
  _globals['_TOKEN']._serialized_start=125
  _globals['_TOKEN']._serialized_end=310
  _globals['_CURRENCYPRICEBUCKET']._serialized_start=313
  _globals['_CURRENCYPRICEBUCKET']._serialized_end=462
  _globals['_PRICE']._serialized_start=464
  _globals['_PRICE']._serialized_end=498
  _globals['_PRICEBUCKET']._serialized_start=500
  _globals['_PRICEBUCKET']._serialized_end=590
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/dex_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/dex_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import block_message_pb2 as solana_dot_block__message__pb2
from solana import token_block_message_pb2 as solana_dot_token__block__message__pb2
from solana import parsed_idl_block_message_pb2 as solana_dot_parsed__idl__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esolana/dex_block_message.proto\x12\x0fsolana_messages\x1a\x1asolana/block_message.proto\x1a solana/token_block_message.proto\x1a%solana/parsed_idl_block_message.proto\"O\n\x07\x44\x65xInfo\x12\x16\n\x0eProgramAddress\x18\x01 \x01(\x0c\x12\x14\n\x0cProtocolName\x18\x02 \x01(\t\x12\x16\n\x0eProtocolFamily\x18\x03 \x01(\t\"\x85\x01\n\tDexMarket\x12\x15\n\rMarketAddress\x18\x01 \x01(\x0c\x12/\n\x0c\x42\x61seCurrency\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\x12\x30\n\rQuoteCurrency\x18\x03 \x01(\x0b\x32\x19.solana_messages.Currency\"\x92\x01\n\x08\x44\x65xOrder\x12\x0f\n\x07OrderId\x18\x01 \x01(\x0c\x12\x0f\n\x07\x42uySide\x18\x02 \x01(\x08\x12\x12\n\nLimitPrice\x18\x03 \x01(\x04\x12\x13\n\x0bLimitAmount\x18\x04 \x01(\x04\x12\x0f\n\x07\x41\x63\x63ount\x18\x05 \x01(\x0c\x12\r\n\x05Owner\x18\x06 \x01(\x0c\x12\r\n\x05Payer\x18\x07 \x01(\x0c\x12\x0c\n\x04Mint\x18\x08 \x01(\x0c\"\xe1\x01\n\x19ParsedPoolLiquidityChange\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12:\n\x07\x43hanges\x18\x05 \x03(\x0b\x32).solana_messages.PoolLiquidityChangeEvent\"\xa6\x02\n\x18PoolLiquidityChangeEvent\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12%\n\x03\x44\x65x\x18\x02 \x01(\x0b\x32\x18.solana_messages.DexInfo\x12*\n\x06Market\x18\x03 \x01(\x0b\x32\x1a.solana_messages.DexMarket\x12/\n\x0c\x42\x61seCurrency\x18\x04 \x01(\x0b\x32\x19.solana_messages.PoolSide\x12\x30\n\rQuoteCurrency\x18\x05 \x01(\x0b\x32\x19.solana_messages.PoolSide\x12:\n\x0bInstruction\x18\x06 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"4\n\x08PoolSide\x12\x14\n\x0c\x43hangeAmount\x18\x02 \x01(\x03\x12\x12\n\nPostAmount\x18\x03 \x01(\x04\"\x94\x02\n\rDexOrderEvent\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12\x30\n\x04Type\x18\x02 \x01(\x0e\x32\".solana_messages.DexOrderEventType\x12%\n\x03\x44\x65x\x18\x03 \x01(\x0b\x32\x18.solana_messages.DexInfo\x12*\n\x06Market\x18\x04 \x01(\x0b\x32\x1a.solana_messages.DexMarket\x12(\n\x05Order\x18\x05 \x01(\x0b\x32\x19.solana_messages.DexOrder\x12:\n\x0bInstruction\x18\x06 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xa0\x01\n\x0c\x44\x65xTradeSide\x12\x0e\n\x06\x41mount\x18\x01 \x01(\x04\x12+\n\x08\x43urrency\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\x12)\n\x07\x41\x63\x63ount\x18\x03 \x01(\x0b\x32\x18.solana_messages.Account\x12(\n\x05Order\x18\x04 \x01(\x0b\x32\x19.solana_messages.DexOrder\"\xaf\x02\n\rDexTradeEvent\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12%\n\x03\x44\x65x\x18\x02 \x01(\x0b\x32\x18.solana_messages.DexInfo\x12*\n\x06Market\x18\x03 \x01(\x0b\x32\x1a.solana_messages.DexMarket\x12*\n\x03\x42uy\x18\x04 \x01(\x0b\x32\x1d.solana_messages.DexTradeSide\x12+\n\x04Sell\x18\x05 \x01(\x0b\x32\x1d.solana_messages.DexTradeSide\x12\x0f\n\x07Royalty\x18\x06 \x01(\x04\x12\x0b\n\x03\x46\x65\x65\x18\x07 \x01(\x04\x12:\n\x0bInstruction\x18\x08 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xc4\x02\n\x14ParsedDexTransaction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12.\n\x06Trades\x18\x05 \x03(\x0b\x32\x1e.solana_messages.DexTradeEvent\x12\x33\n\x0bOrderEvents\x18\x06 \x03(\x0b\x32\x1e.solana_messages.DexOrderEvent\x12=\n\nPoolEvents\x18\x07 \x03(\x0b\x32).solana_messages.PoolLiquidityChangeEvent\"\x82\x01\n\x15\x44\x65xParsedBlockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12;\n\x0cTransactions\x18\x02 \x03(\x0b\x32%.solana_messages.ParsedDexTransaction*5\n\x11\x44\x65xOrderEventType\x12\x08\n\x04OPEN\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x43\x41NCEL\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.dex_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEXORDEREVENTTYPE']._serialized_start=2305
  _globals['_DEXORDEREVENTTYPE']._serialized_end=2358
  _globals['_DEXINFO']._serialized_start=152
  _globals['_DEXINFO']._serialized_end=231
  _globals['_DEXMARKET']._serialized_start=234
  _globals['_DEXMARKET']._serialized_end=367
  _globals['_DEXORDER']._serialized_start=370
  _globals['_DEXORDER']._serialized_end=516
  _globals['_PARSEDPOOLLIQUIDITYCHANGE']._serialized_start=519
  _globals['_PARSEDPOOLLIQUIDITYCHANGE']._serialized_end=744
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_start=747
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_end=1041
  _globals['_POOLSIDE']._serialized_start=1043
  _globals['_POOLSIDE']._serialized_end=1095
  _globals['_DEXORDEREVENT']._serialized_start=1098
  _globals['_DEXORDEREVENT']._serialized_end=1374
  _globals['_DEXTRADESIDE']._serialized_start=1377
  _globals['_DEXTRADESIDE']._serialized_end=1537
  _globals['_DEXTRADEEVENT']._serialized_start=1540
  _globals['_DEXTRADEEVENT']._serialized_end=1843
  _globals['_PARSEDDEXTRANSACTION']._serialized_start=1846
  _globals['_PARSEDDEXTRANSACTION']._serialized_end=2170
  _globals['_DEXPARSEDBLOCKMESSAGE']._serialized_start=2173
  _globals['_DEXPARSEDBLOCKMESSAGE']._serialized_end=2303
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asolana/block_message.proto\x12\x0fsolana_messages\"z\n\x07\x41\x63\x63ount\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x10\n\x08IsSigner\x18\x02 \x01(\x08\x12\x12\n\nIsWritable\x18\x03 \x01(\x08\x12.\n\x05Token\x18\x04 \x01(\x0b\x32\x1a.solana_messages.TokenInfoH\x00\x88\x01\x01\x42\x08\n\x06_Token\"S\n\tTokenInfo\x12\x0c\n\x04Mint\x18\x01 \x01(\x0c\x12\r\n\x05Owner\x18\x02 \x01(\x0c\x12\x10\n\x08\x44\x65\x63imals\x18\x03 \x01(\r\x12\x11\n\tProgramId\x18\x04 \x01(\x0cJ\x04\x08\x05\x10\x06\"N\n\rBalanceUpdate\x12\x12\n\nPreBalance\x18\x01 \x01(\x04\x12\x13\n\x0bPostBalance\x18\x02 \x01(\x04\x12\x14\n\x0c\x41\x63\x63ountIndex\x18\x03 \x01(\r\"\xc0\x02\n\x0bInstruction\x12\x1b\n\x13ProgramAccountIndex\x18\x01 \x01(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x02 \x01(\x04\x12\x12\n\nInnerIndex\x18\x03 \x01(\x04\x12\x14\n\x0cNestingLevel\x18\x04 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\x16\n\x0e\x41\x63\x63ountIndexes\x18\x06 \x03(\r\x12\x36\n\x0e\x42\x61lanceUpdates\x18\x07 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12;\n\x13TokenBalanceUpdates\x18\x08 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12:\n\x12TokenSupplyUpdates\x18\t \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\"\x9b\x01\n\x11TransactionHeader\x12\x0b\n\x03\x46\x65\x65\x18\x01 \x01(\x04\x12\x10\n\x08\x46\x65\x65Payer\x18\x02 \x01(\x0c\x12\x17\n\x0fRecentBlockhash\x18\x03 \x01(\x0c\x12\x0e\n\x06Signer\x18\x04 \x01(\x0c\x12\x12\n\nSignatures\x18\x05 \x03(\x0c\x12*\n\x08\x41\x63\x63ounts\x18\x06 \x03(\x0b\x32\x18.solana_messages.Account\"\x83\x01\n\x06Reward\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x03\x12\x13\n\x0bPostBalance\x18\x03 \x01(\x04\x12/\n\nRewardType\x18\x04 \x01(\x0e\x32\x1b.solana_messages.RewardType\x12\x12\n\nCommission\x18\x05 \x01(\x04\":\n\x11TransactionStatus\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x14\n\x0c\x45rrorMessage\x18\x02 \x01(\t\"\xd8\x02\n\x0bTransaction\x12\x11\n\tSignature\x18\x01 \x01(\x0c\x12\x32\n\x06Status\x18\x02 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12;\n\x13TotalBalanceUpdates\x18\x04 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12@\n\x18TotalTokenBalanceUpdates\x18\x05 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12\x32\n\x0cInstructions\x18\x07 \x03(\x0b\x32\x1c.solana_messages.Instruction\x12\x0c\n\x04Logs\x18\x08 \x03(\t\x12\r\n\x05Index\x18\t \x01(\x04\"t\n\x0b\x42lockHeader\x12\x0c\n\x04Slot\x18\x01 \x01(\x04\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\x12\x12\n\nParentSlot\x18\x04 \x01(\x04\x12\x0e\n\x06Height\x18\x05 \x01(\x04\x12\x11\n\tTimestamp\x18\x06 \x01(\x03\x12\x12\n\nParentHash\x18\x07 \x01(\x0c\"\x9a\x01\n\x0c\x42lockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12(\n\x07Rewards\x18\x02 \x03(\x0b\x32\x17.solana_messages.Reward\x12\x32\n\x0cTransactions\x18\x03 \x03(\x0b\x32\x1c.solana_messages.Transaction*O\n\nRewardType\x12\x15\n\x11RewardTypeUnknown\x10\x00\x12\x07\n\x03\x46\x65\x65\x10\x01\x12\x08\n\x04Rent\x10\x02\x12\x0b\n\x07Staking\x10\x03\x12\n\n\x06Voting\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REWARDTYPE']._serialized_start=1633
  _globals['_REWARDTYPE']._serialized_end=1712
  _globals['_ACCOUNT']._serialized_start=47
  _globals['_ACCOUNT']._serialized_end=169
  _globals['_TOKENINFO']._serialized_start=171
  _globals['_TOKENINFO']._serialized_end=254
  _globals['_BALANCEUPDATE']._serialized_start=256
  _globals['_BALANCEUPDATE']._serialized_end=334
  _globals['_INSTRUCTION']._serialized_start=337
  _globals['_INSTRUCTION']._serialized_end=657
  _globals['_TRANSACTIONHEADER']._serialized_start=660
  _globals['_TRANSACTIONHEADER']._serialized_end=815
  _globals['_REWARD']._serialized_start=818
  _globals['_REWARD']._serialized_end=949
  _globals['_TRANSACTIONSTATUS']._serialized_start=951
  _globals['_TRANSACTIONSTATUS']._serialized_end=1009
  _globals['_TRANSACTION']._serialized_start=1012
  _globals['_TRANSACTION']._serialized_end=1356
  _globals['_BLOCKHEADER']._serialized_start=1358
  _globals['_BLOCKHEADER']._serialized_end=1474
  _globals['_BLOCKMESSAGE']._serialized_start=1477
  _globals['_BLOCKMESSAGE']._serialized_end=1631
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/dex_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'evm/dex_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2
from evm import token_block_message_pb2 as evm_dot_token__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65vm/dex_block_message.proto\x12\x0c\x65vm_messages\x1a\x17\x65vm/block_message.proto\x1a\x1d\x65vm/token_block_message.proto\"\xc6\x02\n\x07\x44\x65xInfo\x12\x15\n\rSmartContract\x18\x01 \x01(\x0c\x12\x11\n\tDelegated\x18\x02 \x01(\x08\x12\x13\n\x0b\x44\x65legatedTo\x18\x03 \x01(\x0c\x12\x14\n\x0cOwnerAddress\x18\x04 \x01(\x0c\x12\x14\n\x0c\x46\x65\x65Recipient\x18\x05 \x01(\x0c\x12\x14\n\x0cProtocolName\x18\x06 \x01(\t\x12\x16\n\x0eProtocolFamily\x18\x07 \x01(\t\x12\x17\n\x0fProtocolVersion\x18\x08 \x01(\t\x12%\n\x04Pair\x18\t \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12+\n\nCurrencies\x18\n \x03(\x0b\x32\x17.evm_messages.TokenInfo\x12\x35\n\x14UnderlyingCurrencies\x18\x0b \x03(\x0b\x32\x17.evm_messages.TokenInfo\"n\n\nTradeAsset\x12)\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x0c\x12\n\n\x02Id\x18\x03 \x01(\x0c\x12\x0b\n\x03URI\x18\x04 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\"e\n\tTradeSide\x12\x0e\n\x06Seller\x18\x01 \x01(\x0c\x12\r\n\x05\x42uyer\x18\x02 \x01(\x0c\x12\x0f\n\x07OrderId\x18\x03 \x01(\x0c\x12(\n\x06\x41ssets\x18\x04 \x03(\x0b\x32\x18.evm_messages.TradeAsset\"s\n\x08TradeFee\x12)\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x0c\x12\n\n\x02Id\x18\x03 \x01(\x0c\x12\r\n\x05Payer\x18\x04 \x01(\x0c\x12\x11\n\tRecipient\x18\x05 \x01(\x0c\"\xe0\x02\n\x08\x44\x65xTrade\x12\x1c\n\x10TransactionIndex\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x11\n\tCallIndex\x18\x02 \x01(\x04\x12\x10\n\x08LogIndex\x18\x03 \x01(\x04\x12\x0e\n\x06HasLog\x18\x04 \x01(\x08\x12\"\n\x03\x44\x65x\x18\x05 \x01(\x0b\x32\x15.evm_messages.DexInfo\x12$\n\x03\x42uy\x18\x06 \x01(\x0b\x32\x17.evm_messages.TradeSide\x12%\n\x04Sell\x18\x07 \x01(\x0b\x32\x17.evm_messages.TradeSide\x12\x0e\n\x06Sender\x18\x08 \x01(\x0c\x12\x0f\n\x07Success\x18\t \x01(\x08\x12$\n\x04\x46\x65\x65s\x18\n \x03(\x0b\x32\x16.evm_messages.TradeFee\x12\r\n\x05Index\x18\x0b \x01(\r\x12:\n\x11TransactionHeader\x18\x0c \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\"\xc7\x01\n\x0f\x44\x65xBlockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12&\n\x06Trades\x18\x05 \x03(\x0b\x32\x16.evm_messages.DexTrade\x12\x30\n\x08L1Header\x18\x06 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x42\x0b\n\t_L1Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.dex_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEXTRADE'].fields_by_name['TransactionIndex']._loaded_options = None
  _globals['_DEXTRADE'].fields_by_name['TransactionIndex']._serialized_options = b'\030\001'
  _globals['_DEXINFO']._serialized_start=102
  _globals['_DEXINFO']._serialized_end=428
  _globals['_TRADEASSET']._serialized_start=430
  _globals['_TRADEASSET']._serialized_end=540
  _globals['_TRADESIDE']._serialized_start=542
  _globals['_TRADESIDE']._serialized_end=643
  _globals['_TRADEFEE']._serialized_start=645
  _globals['_TRADEFEE']._serialized_end=760
  _globals['_DEXTRADE']._serialized_start=763
  _globals['_DEXTRADE']._serialized_end=1115
  _globals['_DEXBLOCKMESSAGE']._serialized_start=1118
  _globals['_DEXBLOCKMESSAGE']._serialized_end=1317
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron/block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'tron/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tron/block_message.proto\x12\rtron_messages\x1a\x17\x65vm/block_message.proto\"\xc6\x01\n\x11TransactionHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x0b\n\x03\x46\x65\x65\x18\x02 \x01(\x03\x12\r\n\x05Index\x18\x03 \x01(\x05\x12\x12\n\nExpiration\x18\x04 \x01(\x03\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\x10\n\x08\x46\x65\x65Limit\x18\x06 \x01(\x03\x12\x11\n\tTimestamp\x18\x07 \x01(\x03\x12\x12\n\nSignatures\x18\x08 \x03(\x0c\x12\x11\n\x04Time\x18\t \x01(\x04H\x00\x88\x01\x01\x12\x10\n\x08\x46\x65\x65Payer\x18\n \x01(\x0c\x42\x07\n\x05_Time\"T\n\x08\x41rgument\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x06String\x18\x02 \x01(\tH\x00\x12\x0e\n\x04UInt\x18\x03 \x01(\x04H\x00\x12\x0f\n\x05\x46loat\x18\x04 \x01(\x01H\x00\x42\x07\n\x05Value\"E\n\x11TransactionResult\x12\x0e\n\x06Status\x18\x01 \x01(\t\x12\x0f\n\x07Success\x18\x02 \x01(\x08\x12\x0f\n\x07Message\x18\x03 \x01(\t\"\x9f\x01\n\x07Receipt\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12\x1a\n\x12\x45nergyPenaltyTotal\x18\x02 \x01(\x03\x12\x11\n\tEnergyFee\x18\x03 \x01(\x03\x12\x18\n\x10\x45nergyUsageTotal\x18\x04 \x01(\x03\x12\x19\n\x11OriginEnergyUsage\x18\x05 \x01(\x03\x12\x10\n\x08NetUsage\x18\x06 \x01(\x03\x12\x0e\n\x06NetFee\x18\x07 \x01(\x03\"\xbe\x02\n\x08\x43ontract\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x18\n\x10\x45xecutionResults\x18\x02 \x03(\x0c\x12\x0c\n\x04Type\x18\x03 \x01(\t\x12\x0f\n\x07TypeUrl\x18\x04 \x01(\t\x12*\n\tArguments\x18\x05 \x03(\x0b\x32\x17.tron_messages.Argument\x12@\n\x14InternalTransactions\x18\x06 \x03(\x0b\x32\".tron_messages.InternalTransaction\x12\x1f\n\x04Logs\x18\x07 \x03(\x0b\x32\x11.evm_messages.Log\x12\"\n\x05Trace\x18\x08 \x01(\x0b\x32\x13.evm_messages.Trace\x12\x35\n\x0eRewardWithdraw\x18\t \x01(\x0b\x32\x1d.tron_messages.RewardWithdraw\"4\n\x16\x43\x61ncelUnfreezeV2Amount\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x03\"C\n\x03Log\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12\x0e\n\x06Topics\x18\x03 \x03(\x0c\x12\r\n\x05Index\x18\x04 \x01(\x05\"/\n\tCallValue\x12\x11\n\tCallValue\x18\x01 \x01(\x03\x12\x0f\n\x07TokenId\x18\x02 \x01(\t\"\xa0\x01\n\x13InternalTransaction\x12\x15\n\rCallerAddress\x18\x01 \x01(\x0c\x12\x0c\n\x04Note\x18\x02 \x01(\t\x12\x19\n\x11TransferToAddress\x18\x03 \x01(\x0c\x12,\n\nCallValues\x18\x04 \x03(\x0b\x32\x18.tron_messages.CallValue\x12\x0c\n\x04Hash\x18\x05 \x01(\x0c\x12\r\n\x05Index\x18\x06 \x01(\x05\"2\n\x0eRewardWithdraw\x12\x10\n\x08Receiver\x18\x01 \x01(\x0c\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x04\"\xc6\x01\n\x0bTransaction\x12\x30\n\x06Header\x18\x01 \x01(\x0b\x32 .tron_messages.TransactionHeader\x12\x30\n\x06Result\x18\x02 \x01(\x0b\x32 .tron_messages.TransactionResult\x12\'\n\x07Receipt\x18\x03 \x01(\x0b\x32\x16.tron_messages.Receipt\x12*\n\tContracts\x18\x04 \x03(\x0b\x32\x17.tron_messages.Contract\"\xc2\x01\n\x0b\x42lockHeader\x12\x0e\n\x06Number\x18\x01 \x01(\x03\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\x12\x11\n\tTimestamp\x18\x03 \x01(\x03\x12\x12\n\nParentHash\x18\x04 \x01(\x0c\x12\x14\n\x0cParentNumber\x18\x05 \x01(\x03\x12\x0f\n\x07Version\x18\x06 \x01(\x05\x12\x12\n\nTxTrieRoot\x18\x07 \x01(\x0c\x12\x18\n\x10\x41\x63\x63ountStateRoot\x18\x08 \x01(\x0c\x12\x19\n\x11TransactionsCount\x18\t \x01(\r\"9\n\x07Witness\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\n\n\x02Id\x18\x02 \x01(\x03\x12\x11\n\tSignature\x18\x03 \x01(\x0c\"\x18\n\x05\x43hain\x12\x0f\n\x07\x43hainId\x18\x01 \x01(\x0c\"\xba\x01\n\x0c\x42lockMessage\x12#\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x14.tron_messages.Chain\x12*\n\x06Header\x18\x02 \x01(\x0b\x32\x1a.tron_messages.BlockHeader\x12\'\n\x07Witness\x18\x03 \x01(\x0b\x32\x16.tron_messages.Witness\x12\x30\n\x0cTransactions\x18\x04 \x03(\x0b\x32\x1a.tron_messages.TransactionB!\n\x12io.bitquery.protosB\x0bTronMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.bitquery.protosB\013TronMessage'
  _globals['_TRANSACTIONHEADER']._serialized_start=69
  _globals['_TRANSACTIONHEADER']._serialized_end=267
  _globals['_ARGUMENT']._serialized_start=269
  _globals['_ARGUMENT']._serialized_end=353
  _globals['_TRANSACTIONRESULT']._serialized_start=355
  _globals['_TRANSACTIONRESULT']._serialized_end=424
  _globals['_RECEIPT']._serialized_start=427
  _globals['_RECEIPT']._serialized_end=586
  _globals['_CONTRACT']._serialized_start=589
  _globals['_CONTRACT']._serialized_end=907
  _globals['_CANCELUNFREEZEV2AMOUNT']._serialized_start=909
  _globals['_CANCELUNFREEZEV2AMOUNT']._serialized_end=961
  _globals['_LOG']._serialized_start=963
  _globals['_LOG']._serialized_end=1030
  _globals['_CALLVALUE']._serialized_start=1032
  _globals['_CALLVALUE']._serialized_end=1079
  _globals['_INTERNALTRANSACTION']._serialized_start=1082
  _globals['_INTERNALTRANSACTION']._serialized_end=1242
  _globals['_REWARDWITHDRAW']._serialized_start=1244
  _globals['_REWARDWITHDRAW']._serialized_end=1294
  _globals['_TRANSACTION']._serialized_start=1297
  _globals['_TRANSACTION']._serialized_end=1495
  _globals['_BLOCKHEADER']._serialized_start=1498
  _globals['_BLOCKHEADER']._serialized_end=1692
  _globals['_WITNESS']._serialized_start=1694
  _globals['_WITNESS']._serialized_end=1751
  _globals['_CHAIN']._serialized_start=1753
  _globals['_CHAIN']._serialized_end=1777
  _globals['_BLOCKMESSAGE']._serialized_start=1780
  _globals['_BLOCKMESSAGE']._serialized_end=1966
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron/token_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'tron/token_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron import block_message_pb2 as tron_dot_block__message__pb2
from evm import token_block_message_pb2 as evm_dot_token__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etron/token_block_message.proto\x12\rtron_messages\x1a\x18tron/block_message.proto\x1a\x1d\x65vm/token_block_message.proto\"\x94\x01\n\x11TokenBlockMessage\x12#\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x14.tron_messages.Chain\x12*\n\x06Header\x18\x02 \x01(\x0b\x32\x1a.tron_messages.BlockHeader\x12.\n\tTransfers\x18\x03 \x03(\x0b\x32\x1b.evm_messages.TokenTransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron.token_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENBLOCKMESSAGE']._serialized_start=107
  _globals['_TOKENBLOCKMESSAGE']._serialized_end=255
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/parsed_idl_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/parsed_idl_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import block_message_pb2 as solana_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%solana/parsed_idl_block_message.proto\x12\x0fsolana_messages\x1a\x1asolana/block_message.proto\"\xaa\x01\n\x0eParsedArgument\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x10\n\x06String\x18\x03 \x01(\tH\x00\x12\x0e\n\x04UInt\x18\x05 \x01(\x04H\x00\x12\r\n\x03Int\x18\x06 \x01(\x03H\x00\x12\x0e\n\x04\x42ool\x18\x07 \x01(\x08H\x00\x12\x0f\n\x05\x46loat\x18\x08 \x01(\x02H\x00\x12\x0e\n\x04Json\x18\t \x01(\tH\x00\x12\x11\n\x07\x41\x64\x64ress\x18\n \x01(\x0cH\x00\x42\x07\n\x05Value\"\xb3\x01\n\x07Program\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06Parsed\x18\x02 \x01(\x08\x12\x0c\n\x04Json\x18\x03 \x01(\t\x12\x11\n\tSignature\x18\x04 \x01(\x0c\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\x0e\n\x06Method\x18\x06 \x01(\t\x12\x32\n\tArguments\x18\x07 \x03(\x0b\x32\x1f.solana_messages.ParsedArgument\x12\x14\n\x0c\x41\x63\x63ountNames\x18\x08 \x03(\t\"\xdf\x03\n\x14ParsedIdlInstruction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05\x44\x65pth\x18\x02 \x01(\r\x12\x10\n\x08\x43\x61llPath\x18\x03 \x03(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x04 \x01(\x05\x12\x17\n\x0f\x41ncestorIndexes\x18\x05 \x03(\r\x12\x19\n\x11\x45xternalSeqNumber\x18\x06 \x01(\r\x12\x19\n\x11InternalSeqNumber\x18\x07 \x01(\r\x12.\n\x07Program\x18\x08 \x01(\x0b\x32\x18.solana_messages.ProgramH\x00\x88\x01\x01\x12*\n\x08\x41\x63\x63ounts\x18\t \x03(\x0b\x32\x18.solana_messages.Account\x12\x0c\n\x04Logs\x18\n \x03(\t\x12\x36\n\x0e\x42\x61lanceUpdates\x18\x0b \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12;\n\x13TokenBalanceUpdates\x18\x0c \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12\x0c\n\x04\x44\x61ta\x18\r \x01(\x0c\x12:\n\x12TokenSupplyUpdates\x18\x0e \x03(\x0b\x32\x1e.solana_messages.BalanceUpdateB\n\n\x08_Program\"\xe5\x02\n\x14ParsedIdlTransaction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12;\n\x13TotalBalanceUpdates\x18\x05 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12@\n\x18TotalTokenBalanceUpdates\x18\x06 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12\x44\n\x15ParsedIdlInstructions\x18\x07 \x03(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xac\x01\n\x15ParsedIdlBlockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12;\n\x0cTransactions\x18\x02 \x03(\x0b\x32%.solana_messages.ParsedIdlTransaction\x12(\n\x07Rewards\x18\x03 \x03(\x0b\x32\x17.solana_messages.Rewardb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.parsed_idl_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PARSEDARGUMENT']._serialized_start=87
  _globals['_PARSEDARGUMENT']._serialized_end=257
  _globals['_PROGRAM']._serialized_start=260
  _globals['_PROGRAM']._serialized_end=439
  _globals['_PARSEDIDLINSTRUCTION']._serialized_start=442
  _globals['_PARSEDIDLINSTRUCTION']._serialized_end=921
  _globals['_PARSEDIDLTRANSACTION']._serialized_start=924
  _globals['_PARSEDIDLTRANSACTION']._serialized_end=1281
  _globals['_PARSEDIDLBLOCKMESSAGE']._serialized_start=1284
  _globals['_PARSEDIDLBLOCKMESSAGE']._serialized_end=1456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron/parsed_abi_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'tron/parsed_abi_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron import block_message_pb2 as tron_dot_block__message__pb2
from evm import parsed_abi_block_message_pb2 as evm_dot_parsed__abi__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#tron/parsed_abi_block_message.proto\x12\rtron_messages\x1a\x18tron/block_message.proto\x1a\"evm/parsed_abi_block_message.proto\">\n\x0c\x43ontractInfo\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x0f\n\x07TypeUrl\x18\x03 \x01(\t\"\x94\x03\n\x14ParsedAbiTransaction\x12;\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32 .tron_messages.TransactionHeader\x12\'\n\x07Receipt\x18\x02 \x01(\x0b\x32\x16.tron_messages.Receipt\x12\x43\n\x11TransactionStatus\x18\x03 \x01(\x0b\x32(.evm_messages.ParsedAbiTransactionStatus\x12;\n\x11TransactionResult\x18\x04 \x01(\x0b\x32 .tron_messages.TransactionResult\x12\x31\n\x0c\x43ontractInfo\x18\x05 \x01(\x0b\x32\x1b.tron_messages.ContractInfo\x12*\n\x05\x43\x61lls\x18\x06 \x03(\x0b\x32\x1b.evm_messages.ParsedAbiCall\x12\x35\n\x0eRewardWithdraw\x18\x07 \x01(\x0b\x32\x1d.tron_messages.RewardWithdraw\"\xcc\x01\n\x15ParsedAbiBlockMessage\x12#\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x14.tron_messages.Chain\x12*\n\x06Header\x18\x02 \x01(\x0b\x32\x1a.tron_messages.BlockHeader\x12\'\n\x07Witness\x18\x03 \x01(\x0b\x32\x16.tron_messages.Witness\x12\x39\n\x0cTransactions\x18\x04 \x03(\x0b\x32#.tron_messages.ParsedAbiTransactionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron.parsed_abi_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CONTRACTINFO']._serialized_start=116
  _globals['_CONTRACTINFO']._serialized_end=178
  _globals['_PARSEDABITRANSACTION']._serialized_start=181
  _globals['_PARSEDABITRANSACTION']._serialized_end=585
  _globals['_PARSEDABIBLOCKMESSAGE']._serialized_start=588
  _globals['_PARSEDABIBLOCKMESSAGE']._serialized_end=792
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxo/parsed_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'utxo/parsed_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from utxo import block_message_pb2 as utxo_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1futxo/parsed_block_message.proto\x12\rutxo_messages\x1a\x18utxo/block_message.proto\"x\n\x12ParsedBlockMessage\x12*\n\x06Header\x18\x01 \x01(\x0b\x32\x1a.utxo_messages.BlockHeader\x12\x36\n\x0cTransactions\x18\x02 \x03(\x0b\x32 .utxo_messages.ParsedTransaction\"\xc2\x01\n\x11ParsedTransaction\x12\x30\n\x06Header\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionHeader\x12\x35\n\x06Inputs\x18\x02 \x03(\x0b\x32%.utxo_messages.ParsedTransactionInput\x12\x37\n\x07Outputs\x18\x03 \x03(\x0b\x32&.utxo_messages.ParsedTransactionOutput\x12\x0b\n\x03\x46\x65\x65\x18\x04 \x01(\x04\"\x85\x01\n\x16ParsedTransactionInput\x12.\n\x05Input\x18\x02 \x01(\x0b\x32\x1f.utxo_messages.TransactionInput\x12;\n\x0bSpentOutput\x18\x03 \x01(\x0b\x32&.utxo_messages.ParsedTransactionOutput\"<\n\x0eMinBlockHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x0e\n\x06Height\x18\x02 \x01(\x03\x12\x0c\n\x04Time\x18\x03 \x01(\x03\"\xe9\x01\n\x17ParsedTransactionOutput\x12\x30\n\x06Output\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionOutput\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12-\n\nScriptType\x18\x03 \x01(\x0e\x32\x19.utxo_messages.ScriptType\x12\x0e\n\x06Script\x18\x04 \x01(\x0c\x12\x0f\n\x07ReqSigs\x18\x05 \x01(\r\x12\r\n\x05Value\x18\x06 \x01(\x04\x12,\n\x05\x42lock\x18\x07 \x01(\x0b\x32\x1d.utxo_messages.MinBlockHeader*\xa9\x01\n\nScriptType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06PUBKEY\x10\x01\x12\x0e\n\nPUBKEYHASH\x10\x02\x12\x0e\n\nSCRIPTHASH\x10\x03\x12\x0c\n\x08MULTISIG\x10\x04\x12\x0c\n\x08NULLDATA\x10\x05\x12\x16\n\x12WITNESS_V0_KEYHASH\x10\x06\x12\x19\n\x15WITNESS_V0_SCRIPTHASH\x10\x07\x12\x13\n\x0fWITNESS_UNKNOWN\x10\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxo.parsed_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCRIPTTYPE']._serialized_start=830
  _globals['_SCRIPTTYPE']._serialized_end=999
  _globals['_PARSEDBLOCKMESSAGE']._serialized_start=76
  _globals['_PARSEDBLOCKMESSAGE']._serialized_end=196
  _globals['_PARSEDTRANSACTION']._serialized_start=199
  _globals['_PARSEDTRANSACTION']._serialized_end=393
  _globals['_PARSEDTRANSACTIONINPUT']._serialized_start=396
  _globals['_PARSEDTRANSACTIONINPUT']._serialized_end=529
  _globals['_MINBLOCKHEADER']._serialized_start=531
  _globals['_MINBLOCKHEADER']._serialized_end=591
  _globals['_PARSEDTRANSACTIONOUTPUT']._serialized_start=594
  _globals['_PARSEDTRANSACTIONOUTPUT']._serialized_end=827
# @@protoc_insertion_point(module_scope)
